#!/usr/bin/env python
# -*- coding: utf-8 -*-
import click

from os.path import splitext
from PIL import Image, ImageDraw, ImageFont

MODE = 'RGBA'
BLACK = (0, 0, 0, 255)
WHITE = (255, 255, 255, 255)


def add_text(img, font, fontsize, text):
    font = ImageFont.truetype(font, fontsize)
    text_width, text_height = font.getsize(text)
    text_img_height = int(text_height * 1.5)

    base_img = Image.new(MODE, (img.size[0], text_img_height + img.size[1]), BLACK)

    text_image = Image.new(MODE, (img.size[0], text_img_height), BLACK)
    draw = ImageDraw.Draw(text_image, MODE)

    # Center text on image.
    pos = ((text_image.size[0] - text_width) / 2, (text_image.size[1] - text_height) / 2)
    draw.text(pos, text, WHITE, font=font)

    base_img.paste(img, (0, 0))
    base_img.paste(text_image, (0, img.size[1]))

    return base_img


@click.command()
@click.option('--inplace', '-i', default=False, is_flag=True,
    help='Edit the image inplace, default is False.')
@click.option('--font', default='arial.ttf',
    help='Set the font family, default is arial.ttf.')
@click.option('--fontsize', default=16,
    help='Set the font size, default is 16.')
@click.option('--quantize', '-q', default=False, is_flag=True,
    help='Quantize the image to reduce its filesize, default is False.')
@click.option('--scale', '-s', type=int,
    help='Set the maximum dimension as an integer value.')
@click.option('--text', '-t',
    help='Set the text to append at the bottom of the image.')
@click.argument('filename')
def main(inplace, font, fontsize, quantize, scale, text, filename):
    img = Image.open(filename)

    if inplace:
        outfile = filename
    else:
        # Insert .wim between file name and extension in the outfile name.
        parts = splitext(filename)
        outfile = parts[0] + '.wim' + parts[1]

    if img.mode != MODE:
        img = img.convert(MODE)

    if quantize:
        img = img.quantize()

    if scale:
        img.thumbnail((scale, scale))

    if text:
        img = add_text(img, font, fontsize, text)

    img.save(outfile)


if __name__ == '__main__':
    main()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import io
from wim import __version__

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

with io.open('README.rst') as f:
    readme = f.read()

with io.open('HISTORY.rst') as f:
    history = f.read().replace('.. :changelog:', '')

with io.open('requirements.txt', encoding='utf-8') as f:
    requirements = f.read().splitlines()

setup(
    name='wim',
    version=__version__,
    description='wim is a command line tool to create Web images.',
    long_description=readme + '\n\n' + history,
    author='Ramiro Gómez',
    author_email='code@ramiro.org',
    url='https://github.com/yaph/wim',
    packages=['wim',],
    package_dir={'wim': 'wim'},
    include_package_data=True,
    install_requires=requirements,
    license='MIT',
    zip_safe=False,
    keywords='wim',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Natural Language :: English',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
    ],
    test_suite='tests',
    entry_points={
        'console_scripts': [
            'wim = wim.wim:main'
        ]
    }
)
